import os
import json
import pandas as pd
from dotenv import load_dotenv

# Load environment variables from .env file
config_dir = os.path.dirname(__file__)
env_path = os.path.join(config_dir, '.env')

if os.path.exists(env_path):
    load_dotenv(dotenv_path=env_path)
else:
    raise FileNotFoundError(f"{env_path} not found.")

# Initialize settings dictionary from environment variables
settings = {
    'data_path': os.getenv('DATA_PATH'),
    'model_path': os.getenv('MODEL_PATH'),
    'approval_key': os.getenv('APPROVAL_KEY'),
    'max_detected_stocks': int(os.getenv('MAX_DETECTED_STOCKS', 99)),
    'data_fetch_interval': int(os.getenv('DATA_FETCH_INTERVAL', 60)),
    'strategy_name': os.getenv('STRATEGY_NAME'),
    'token_path': os.getenv('TOKEN_PATH'),
    'appkey': os.getenv('APPKEY'),
    'appsecret': os.getenv('APPSECRET'),
    'user_id': os.getenv('USER_ID'),
    'trading_url': os.getenv('TRADING_URL'),
    'agent': os.getenv('AGENT'),
    'acct_stock': os.getenv('ACCT_STOCK'),
    'prod': os.getenv('PROD'),
    'cano': os.getenv('CANO'),
    'seq': os.getenv('SEQ'),
    'prod_url': os.getenv('PROD_URL'),
    'app_key': os.getenv('APP_KEY'),
    'app_secret': os.getenv('APP_SECRET'),
    'email_sender': os.getenv('EMAIL_SENDER'),
    'email_password': os.getenv('EMAIL_PASSWORD'),
    'email_receiver': os.getenv('EMAIL_RECEIVER'),
    'ECOS_API_KEY': os.getenv('JIUN3YBFR9JWR4Y9G2KT')
}

# Load additional settings from config.json
config_json_path = os.path.join(config_dir, 'config.json')

if os.path.exists(config_json_path):
    with open(config_json_path, 'r') as f:
        config_settings = json.load(f)
        settings.update(config_settings)
else:
    raise FileNotFoundError(f"{config_json_path} not found.")

# Example of saving a DataFrame to a CSV file in the network folder
def save_to_csv(data, filename):
    file_path = os.path.join(settings['data_path'], filename)
    data.to_csv(file_path, index=False)
    print(f"Data saved to {file_path}")

# Example of loading a DataFrame from a CSV file in the network folder
def load_from_csv(filename):
    file_path = os.path.join(settings['data_path'], filename)
    if os.path.exists(file_path):
        data = pd.read_csv(file_path)
        print(f"Data loaded from {file_path}")
        return data
    else:
        print(f"{file_path} does not exist.")
        return None

# Example usage
df = pd.DataFrame({'A': [1, 2, 3], 'B': [4, 5, 6]})
save_to_csv(df, 'example.csv')

loaded_df = load_from_csv('example.csv')
print(loaded_df)
